lcvtoolbox.integrations.huggingface.dataset\_sync.datetime
==========================================================

.. currentmodule:: lcvtoolbox.integrations.huggingface.dataset_sync

.. autoclass:: datetime
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~datetime.__init__
      ~datetime.astimezone
      ~datetime.combine
      ~datetime.ctime
      ~datetime.date
      ~datetime.dst
      ~datetime.fromisocalendar
      ~datetime.fromisoformat
      ~datetime.fromordinal
      ~datetime.fromtimestamp
      ~datetime.isocalendar
      ~datetime.isoformat
      ~datetime.isoweekday
      ~datetime.now
      ~datetime.replace
      ~datetime.strftime
      ~datetime.strptime
      ~datetime.time
      ~datetime.timestamp
      ~datetime.timetuple
      ~datetime.timetz
      ~datetime.today
      ~datetime.toordinal
      ~datetime.tzname
      ~datetime.utcfromtimestamp
      ~datetime.utcnow
      ~datetime.utcoffset
      ~datetime.utctimetuple
      ~datetime.weekday
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~datetime.day
      ~datetime.fold
      ~datetime.hour
      ~datetime.max
      ~datetime.microsecond
      ~datetime.min
      ~datetime.minute
      ~datetime.month
      ~datetime.resolution
      ~datetime.second
      ~datetime.tzinfo
      ~datetime.year
   
   